let worldMap;


function setup() {
  createCanvas(800, 480);
  background(224);

  // If you change the dimensions, the aspect ratio will stay the same.
  // The browser will size the map to use as much of the width/height as possible.
  let mapWidth = width * 0.8;  // use 80% of the sketch size
  let mapHeight = height * 0.8;
  // Center the map on the screen. The mapX and mapY
  // coordinates are relative to the sketch location.
  let mapX = (width - mapWidth) / 2;
  let mapY = (height - mapHeight) / 2;

  let mapPath = "data/world-robinson.svg";
  //let mapPath = "data/world-equirectangular.svg";
  //let mapPath = "data/us-counties.svg";
  //let mapPath = "data/us-states.svg";

  // This will create a new SVG map from the 'robinson.svg' file in the data folder.
  // Once the map has finished loading, the mapReady() function will be called.
  worldMap = new SimpleSVG(mapPath, mapX, mapY, mapWidth, mapHeight, mapReady);
}


// this function is called when the map loads
function mapReady() {
  // show a list of all the shapes by name (i.e all the country codes)
  print(worldMap.listShapes());

  // call the function named 'mapClick' whenever a shape is clicked
  worldMap.onClick(mapClick);

  // handle mouseover (hover) events, and mouseout (the opposite of hover)
  worldMap.onMouseOver(mapOver);
  worldMap.onMouseOut(mapOut);
}


function mapClick(shape) {
  if (!ignoreShape(shape.id)) {
    worldMap.setFill(shape, 'red');
  }
  print(`click ${shape.id}`);
}


function mapOver(shape) {
  if (!ignoreShape(shape.id)) {
    worldMap.setFill(shape, '#666');
  }
  print(`over ${shape.id}`);
}


function mapOut(shape) {
  if (!ignoreShape(shape.id)) {
    worldMap.setFill(shape, '#ccc');
  }
  print(`out ${shape.id}`);
}


// returns 'true' if this shape should be ignored
// i.e. if it's the ocean or it's the boundary lines between states
function ignoreShape(name) {
  return (name === 'ocean' || name.startsWith('lines-'));
}


function draw() {
  // Your sketch can go here, but keep in mind that the map will always be on top.
}
